{% extends "menu.html" %}
{% block title %}GEA | Gráficos{% endblock %}
{% block css %}
  {% load chartit %}
  {{ epapivcht|load_charts:"container" }}
{% endblock %}
{% block content %}
  {% load static from staticfiles %}
      <div class="col-md-12 jumbotron">
        <img src="{% static "img/folder.png" %}" alt="Expedientes" height="120px" class="pull-right">
        <h1><i class="fa fa-globe"></i> <a href="/">GEA</a></h1>
        <h4><strong>G</strong>estión de <strong>E</strong>xpedientes de <strong>A</strong>grimensores</h4>
      </div>
      <div id='container'> Chart will be rendered here </div>
{% endblock %}
{% block footer %}{% endblock %}
