{% extends "menu.html" %}
{% block title %}GEA | Listado Expedientes{% endblock title %}

{# set menu in active mode #}
{% block nav-list-cl %} class="active"{% endblock %}

{% block content %}
{% load tags %}

<div class="page-header">
  <h1>
    <i class="fa fa-map-signs"></i> <a href="{% url 'catastros_locales' %}">Catastros Locales</a>
    {% if lugar %}<font size=4>{{ lugar }}
    {% if seccion == 'all' %}- sección:todas{% else %}- sección:<strong>{{ seccion }}</strong>{% endif %}
    {% if manzana == 'all' %}- manzana:todas{% else %}- manzana:<strong>{{ manzana }}</strong>{% endif %}
    {% if parcela == 'all' %}- parcela:todas{% else %}- parcela:<strong>{{ parcela }}</strong>{% endif %}
    {% if cl %}(Total: <strong>{{ cl.paginator.count }}</strong>){% endif %}
    </font>{% endif %}
  </h1>
</div>

<!-- Lugares -->
<div class="well well-sm">
  <div class="row">
    <div class="col-lg-1">Lugares</div>
    <div class="dropdown col-lg-4">
      <button class="btn btn-sm btn-default dropdown-toggle" type="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="true">
        Lugar
        <span class="caret"></span>
      </button>
      <ul class="dropdown-menu">
        {% for l in lugares %}
        <li{% if lugar == l %} class="active"{% endif %}><a href="{% url 'catastros_locales' %}{{ l }}/">{{ l }}</a></li>
        {% endfor %}
      </ul>
      {% if lugar %}<strong>{{ lugar }}</strong>{% else %}Ninguno{% endif %}
    </div>
    <div class="col-lg-1">Secciones</div>
    <div class="col-lg-6 btn-group btn-group-sm" role="group">
      <a href="{% url 'catastros_locales' %}{{ lugar}}/all/" class="btn {% if seccion == 'all' %} btn-default active{% else %} btn-info{% endif %}">*</a>
      {% for s in secciones %}
      <a href="{% url 'catastros_locales' %}{{ lugar}}/{{ s }}/" class="btn{% if seccion == s %} btn-default active{% else %} btn-primary{% endif %}">{{ s }}</a>
      {% endfor %}
    </div>
  </div>
  <div class="row">
    <div class="col-lg-1">Manzanas</div>
    <div class="col-lg-11 btn-group btn-group-sm" role="group">
      <a href="{% url 'catastros_locales' %}{{ lugar}}/{{ seccion }}/all/" class="btn {% if manzana == 'all' %} btn-default active{% else %} btn-info{% endif %}">*</a>
      {% for m in manzanas %}
      <a href="{% url 'catastros_locales' %}{{ lugar}}/{{ seccion }}/{{ m }}/" class="btn{% if manzana == m %} btn-default active{% else %} btn-primary{% endif %}">{{ m }}</a>
      {% endfor %}
    </div>
    <div class="col-lg-1">Parcelas</div>
    <div class="col-lg-11 btn-group btn-group-sm" role="group">
      <a href="{% url 'catastros_locales' %}{{ lugar}}/{{ seccion }}/{{ manzana }}/all/" class="btn {% if parcela == 'all' %} btn-default active{% else %} btn-info{% endif %}">*</a>
      {% for p in parcelas %}
      <a href="{% url 'catastros_locales' %}{{ lugar}}/{{ seccion }}/{{ manzana }}/{{ p }}/" class="btn{% if parcela == p %} btn-default active{% else %} btn-primary{% endif %}">{{ p }}</a>
      {% endfor %}
    </div>
  </div>
</div>

{% if cl %}
{% with page_obj=cl %}
{#{% include "_pagination.html" %}#}
<nav class="text-center">
  <ul class="pagination pagination-sm">
    {% if page_obj.has_previous %}
    <li><a href="?page=1">Primera</a></li>
    <li><a href="?page={{ page_obj.previous_page_number }}">&laquo; Anterior</a></li>
    {% endif %}
    {% for pg in page_obj.paginator.page_range %}
      {% if page_obj.number < pg|add:"5"  and page_obj.number > pg|add:"-5" %}
        {% if page_obj.number == pg %}
    <li class="active"><a href="?page={{ pg }}">{{ pg }}</a></li>
        {% else %}
    <li><a href="?page={{ pg }}">{{ pg }}</a></li>
        {% endif %}
      {% endif %}
    {% endfor %}
    {% if page_obj.has_next %}
    <li><a href="?page={{ page_obj.next_page_number }}">Siguiente &raquo;</a></li>
    <li><a href="?page={{ page_obj.paginator.num_pages }}">Última ({{ page_obj.paginator.num_pages }})</a></li>
    {% endif %}
  </ul>
</nav>

<table class="table table-bordered table-condensed table-hover">
  <thead>
    <tr>
      <th>Expediente</th>
      <th>Persona(s)</th>
      <th>Lugar(es)</th>
      <th>Partida(s)</th>
      <th>Plano</th>
    </tr>
  </thead>
  <tbody>
    {% for e in cl %}
    <tr>
      <td>
        <a href="/admin/gea/expediente/{{ e.id }}/">{{ e.id }}</a>
      </td>
      <td>
      {% if e.expedientepersona_set %}
        {% for ep in e.expedientepersona_set.all %}
        <a href="/admin/gea/persona/{{ ep.persona.id }}/">{{ ep.persona.apellidos }} {{ ep.persona.nombres }}</a> {% if ep.comitente %}(Comitente){% endif %} {% if ep.persona.telefono or ep.persona.celular %}({{ ep.persona.telefono }} / {{ ep.persona.celular }}){% endif %}<br />
        {% endfor %}
      {% endif %}
      </td>
      <td>
      {% if e.expedientelugar_set %}
        {% for el in e.expedientelugar_set.all %}
        <a href="/admin/gea/lugar/{{ el.lugar.id }}/">{{ el.lugar.nombre }}</a> {% for c in el.catastrolocal_set.all %}<br />{{ c }}{% endfor %}
          {% if not forloop.last %}<br />{% endif %}
        {% endfor %}
      {% endif %}
      </td>
      <td>
      {% if e.expedientepartida_set %}
        {% for ep in e.expedientepartida_set.all %}
          {% if ep.set_ruta %}<a href="{{ ep.set_ruta }}">{% endif %}{{ ep.partida.sd }}-{{ ep.partida }}{% if ep.set_ruta %}</a>{% endif %}
          {% if not forloop.last %}<br />{% endif %}
        {% endfor %}
      {% endif %}
      </td>
      <td>
        {% if e.plano_ruta %}<a href="{{ e.plano_ruta }}">{% endif %}{% if e.inscripcion_numero %}{{ e.inscripcion_numero }}{% endif %}{% if e.plano_ruta %}</a>{% endif %}
        {% if e.inscripcion_fecha %}({{ e.inscripcion_fecha }}){% endif %}
      </td>
    </tr>
    {% endfor %}
  </tbody>
</table>
{#{% include "_pagination.html" %}#}
{% endwith %}
{% else %}
<div class="alert alert-info" role="alert">
  <i class="fa fa-info-circle" aria-hidden="true"></i>
  <span class="sr-only">Información:</span>
  No se encontraron Expedientes.
</div>
{% endif %}
{% endblock %}
